clear all

* Set Folder to output one

cd ..\Outputs

* Call dataset of revisions and shocks combined (COMB)

use COMB, clear

gen time=year+(qua-1)/4
egen t=group(year quarter)
tsset t

capture drop MPOa
gen MPOa=MPO
replace MPOa=0 if MPO==. & year>2008

gen dlogY=log(GDPC96/l.GDPC96)*400

* Dummy variable for the Great Recession

gen DGR=(time==2008 | time==2008.25 | time==2008.5 | time==2008.75 | time==2009 | time==2009.25)

gen     semester=1 if quarter==1 | quarter==2
replace semester=2 if quarter==3 | quarter==4

collapse (sum) TFP sFP1SPF1 FP2 DE1 DE2 OIL OILK OILBH MPOa MPVAR0 ///
		 (mean) CBOgRpot0 CBOgRpot5y dlogY DGR ///
		 , by(year semester)
		 
sort year semester
gen t=_n
tsset t

gen D911=(year==2001 & semester==2)
			 
local confidenceval=0.95

if `confidenceval'==1.65 local confidencestr="90%"
if `confidenceval'==0.95 local confidencestr="66%"
			
*===============================================================================
*			        Variables with contemporanous response
*===============================================================================

quiet foreach var in TFP sFP1SPF1 FP2 DE1 OILK OILBH MPOa {
	
	noisily di "====================================================="
	noisily di "			`var'"
	noisily di "====================================================="
	
	* Define strings for titles of IRF figures
	
	if "`var'"=="TFP" local var_str="TFP shock (Fernald)"
	if "`var'"=="sFP1SPF1" local var_str="Gov't spending shock (AG 2012)"
	if "`var'"=="DE1" local var_str="Military spending shock (Ramey 2016)"
	if "`var'"=="DE2" local var_str="Military spending shock (Ramey 2016)"
	if "`var'"=="OIL" local var_str="Oil supply shock (Kilian 2004)"
	if "`var'"=="OILK" local var_str="Oil supply shock (Kilian 2009)"
	if "`var'"=="OILBH" local var_str="Oil supply shock (Baumeister and Hamilton 2015)"
	if "`var'"=="FP2" local var_str="Tax shock (Romer and Romer 2010)"
	if "`var'"=="MPOa" local var_str="Monetary policy shock (Romer and Romer 2004)"
	if "`var'"=="MPVAR0" local var_str="Monetary policy shock (VAR)"
	
	capture drop Z*
	gen Z=`var'
	sum Z
	replace Z=Z/r(sd)
	
	* Create current and lagged values of the shock
	
	forvalues i=0(1)4 {
		gen Z`i'=l`i'.Z
	}
	
	reg CBOgRpot0 dlogY Z?
	capture drop smpl0
	gen smpl0=e(sample)
	drop Z
	
	capture drop irf*
	*** time for IRFs
	gen irf_0=t-1
	
	*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	*				       IRF for potential output
	*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	
	ivregress 2sls CBOgRpot0 Z* D911 DGR if smpl0==1, vce(hac nw 4)
	
	gen irf_pot_m=.
	gen irf_pot_se=.
	local str0="Z0"
	lincom "`str0'"
	replace irf_pot_m=r(estimate) if irf_0==0
	replace irf_pot_se=r(se) if irf_0==0
		
	forvalues i=1(1)4 {
		local str0="`str0'" + "+Z`i'" 
		lincom "`str0'"
		replace irf_pot_m=r(estimate) if irf_0==`i'
		replace irf_pot_se=r(se) if irf_0==`i'
	}	
	
	gen irf_pot_m_up=irf_pot_m+`confidenceval'*irf_pot_se
	gen irf_pot_m_lo=irf_pot_m-`confidenceval'*irf_pot_se
	
	*** test cumulative sum for the potential is zero
	lincom Z0+Z1+Z2+Z3+Z4
	local pval_pot_irf=strofreal((1-normal(abs(r(estimate)/r(se))))*2,"%4.3f") 
	
	*** test pointwise that the potential output IRF (growth rate) is zero for the growth rate
	test Z0 Z1 Z2 Z3 Z4
	local pval_pot_irf_point=strofreal(r(p),"%4.3f") 

	*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	*				         IRF for actual output
	*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	
	* newey dlogY Z* D911 DGR if smpl0==1, lag(4)
	ivregress 2sls dlogY Z* D911 DGR if smpl0==1, vce(hac nw 4)

	gen irf_act_m=.
	gen irf_act_se=.	
	local str0="Z0"
	lincom "`str0'"
	replace irf_act_m=r(estimate) if irf_0==0
	replace irf_act_se=r(se) if irf_0==0
		
	forvalues i=1(1)4 {
		local str0="`str0'" + "+Z`i'" 
		lincom "`str0'"
		replace irf_act_m=r(estimate) if irf_0==`i'
		replace irf_act_se=r(se) if irf_0==`i'
	}		
		
	gen irf_act_m_up=irf_act_m+`confidenceval'*irf_act_se
	gen irf_act_m_lo=irf_act_m-`confidenceval'*irf_act_se		

	*** test cumulative sum for the actual is zero	
	lincom Z0+Z1+Z2+Z3+Z4
	local pval_act_irf=strofreal((1-normal(abs(r(estimate)/r(se))))*2,"%4.3f")
	*** test pointwise that the actual output IRF (growth rate) is zero for the growth rate
	test Z0 Z1 Z2 Z3 Z4
	local pval_act_irf_point=strofreal(r(p),"%4.3f") 

	*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	*				     IRF for actual output - potential
	*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	
	capture drop D_actual_minus_potential
	gen D_actual_minus_potential=dlogY-CBOgRpot0
	* newey D_actual_minus_potential Z* D911 DGR if smpl0==1, lag(4)
	ivregress 2sls D_actual_minus_potential Z* D911 DGR if smpl0==1, vce(hac nw 4)

	*** test cumulative sum for the actual is zero	
	lincom Z0+Z1+Z2+Z3+Z4
	local pval_dif_irf=strofreal((1-normal(abs(r(estimate)/r(se))))*2,"%4.3f")

	*** test pointwise that the actual output IRF (growth rate) is zero for the growth rate
	test Z0 Z1 Z2 Z3 Z4
	local pval_dif_irf_point=strofreal(r(p),"%4.3f") 

	noisily di "p-val equality of IRFs:  (`pval_dif_irf') [`pval_dif_irf_point']"
	noisily di "p-val actual IRF:  (`pval_act_irf') [`pval_act_irf_point']"
	noisily di "p-val potential IRF: (`pval_pot_irf') [`pval_pot_irf_point']"
		
	*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	*				   IRF for potential output (5 years out)
	*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	
	ivregress 2sls CBOgRpot5y Z* D911 DGR if smpl0==1, vce(hac nw 4)
	
	gen irf_pot5_m=.
	gen irf_pot5_se=.
	local str0="Z0"
	lincom "`str0'"
	replace irf_pot5_m=r(estimate) if irf_0==0
	replace irf_pot5_se=r(se) if irf_0==0
		
	forvalues i=1(1)4 {
		local str0="`str0'" + "+Z`i'" 
		lincom "`str0'"
		replace irf_pot5_m=r(estimate) if irf_0==`i'
		replace irf_pot5_se=r(se) if irf_0==`i'
	}	
	
	gen irf_pot5_m_up=irf_pot5_m+`confidenceval'*irf_pot5_se
	gen irf_pot5_m_lo=irf_pot5_m-`confidenceval'*irf_pot5_se
	
	*** test cumulative sum for the potential is zero
	lincom Z0+Z1+Z2+Z3+Z4
	local pval_pot5_irf=strofreal((1-normal(abs(r(estimate)/r(se))))*2,"%4.3f") 
	
	*** test pointwise that the potential output IRF (growth rate) is zero for the growth rate
	test Z0 Z1 Z2 Z3 Z4
	local pval_pot5_irf_point=strofreal(r(p),"%4.3f") 
	
	noisily di "p-val potential 5 year IRF: (`pval_pot5_irf') [`pval_pot5_irf_point']"

	*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	*				 IRF for actual output - potential (5 year)
	*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	
	capture drop D_actual_minus_potential5
	gen D_actual_minus_potential5=dlogY-CBOgRpot5y
	ivregress 2sls D_actual_minus_potential5 Z* D911 DGR if smpl0==1, vce(hac nw 4)

	*** test cumulative sum for the actual is zero	
	lincom Z0+Z1+Z2+Z3+Z4
	local pval_dif5_irf=strofreal((1-normal(abs(r(estimate)/r(se))))*2,"%4.3f")

	*** test pointwise that the actual output IRF (growth rate) is zero for the growth rate
	test Z0 Z1 Z2 Z3 Z4
	local pval_dif5_irf_point=strofreal(r(p),"%4.3f") 
	noisily di "p-val equality of IRFs (5 year):  (`pval_dif_irf') [`pval_dif_irf_point']"

	twoway ///
	(rarea irf_act_m_lo irf_act_m_up irf_0 if irf_0<=4, color(gs14)) ///
	(line irf_act_m  irf_0 if irf_0<=4, lcolor(black) lpattern(solid) lwidth(thick)) ///
	(line irf_pot_m  irf_0 if irf_0<=4, lcolor(blue) lpattern(solid)) ///
	(line irf_pot_m_up  irf_0 if irf_0<=4, lcolor(blue) lpattern(longdash)) ///
	(line irf_pot_m_lo  irf_0 if irf_0<=4, lcolor(blue) lpattern(longdash)) ///
	(scatter irf_pot5_m  irf_0 if irf_0<=4, connect(direct) lcolor(red) msymbol(o) msize(3) mcolor(red) mfcolor(white) lpattern(solid)) ///
	(line irf_pot5_m_up  irf_0 if irf_0<=4, lcolor(red) lpattern(shortdash)) ///
	(line irf_pot5_m_lo  irf_0 if irf_0<=4, lcolor(red) lpattern(shortdash)) ///		
	, ///
	xtitle("") xlabel(0(1)4) ///
	ytitle("output growth rate, percent, annualized") ///
	title("`var_str'") ///
	legend(order(2 1 3 4 6 7 9) ///
	label(1 "`confidencestr' CI") ///
	label(2 "Actual Output   , (`pval_act_irf') [`pval_act_irf_point']") ///
	label(3 "Poten. (nowcast), (`pval_pot_irf') [`pval_pot_irf_point']") ///
	label(4 "`confidencestr' CI") ///
	label(6 "Poten. (5 years), (`pval_pot5_irf') [`pval_pot5_irf_point']") ///
	label(7 "`confidencestr' CI") ///
	label(9 "Actual=Poten.   , (`pval_dif_irf') [`pval_dif_irf_point']") ///
	rows(4) ring(3) position(7)) ///
	graphregion(color(white)) bgcolor(white) ///
	name(`var', replace)			
		
}

window manage close graph _all
graph combine TFP FP2 OILK, rows(1) ysize(2) graphregion(color(white)) plotregion(color(white)) t1title(Panel A: Supply Shocks) name(panela, replace)
graph combine MPOa DE1 sFP1SPF1, rows(1) ysize(2) graphregion(color(white)) plotregion(color(white)) t1title(Panel B: Demand Shocks) name(panelb, replace)

window manage close graph _all
graph combine panela panelb, rows(2) altshrink graphregion(color(white)) plotregion(color(white))
